<?php
define("MSG_BAD_CREDENTIALS","The supplied credentials (login or password) are invalid.");
define("MSG_BAD_DMUX","Cannot add Dmux %s, with grid %s and output ports %d");
define("MSG_BAD_THRESHOLD_VALUE","Invalid threshold value %s for field: %s");
define("MSG_BAD_ROTAU_IP","Cannot connect to ROTAU with Ip address %s");
define("MSG_CHINESE","中文");
define("MSG_CONNECTION","Connect");
define("MSG_COPYRIGHT_SHORT","Copyright © 2023 VIAVI. All rights reserved.");
define("MSG_ENGLISH","English");
define("MSG_ERROR_ADD_LOCALISATION_ERROR","Add localisation error"); 
define("MSG_ERROR_ALARM_UNDEFINED","Undefined alarm");
define("MSG_ERROR_ALARM_FETCH_FAILED","Failed to retrieve alarm: ");
define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","Failed to apply database patches!");
define("MSG_ERROR_CLEAR_TEST_ALARM","Failed to remove the test alarms!");
define("MSG_ERROR_COMMIT_TRANSACTION","Save operations failed due to transaction commit failure!");
define("MSG_ERROR_CONNECTION_FAILED","Failed to open connection!");
define("MSG_ERROR_COPY_FAILED","File copy failed!");
define("MSG_ERROR_COULD_NOT_ACQUIRE_LOCK","Failed to acquire lock!");
define("MSG_ERROR_COULD_NOT_CREATE_FILE","Could not create file: ");
define("MSG_ERROR_COULD_NOT_CREATE_SNAPSHOT","Could not create Snapshot! ");
define("MSG_ERROR_COULD_NOT_CREATE_BACKUP","Could not create OTU backup!");
define("MSG_ERROR_COULD_NOT_CREATE_GPS_FILE","Could not create GPS file!");
define("MSG_ERROR_CREATE_DATABASE_MODEL_FAILURE","Database model couldn't be created!");
define("MSG_ERROR_DELETE_LINK","Failed to remove the link!");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_FAILED","Delete alarms on test failed!");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_ON_TEST_FAILED","Delete alarms on test %d failed!");
define("MSG_ERROR_DELETE_TEST","Failed to remove the test!");
define("MSG_ERROR_DTO_NOT_FOUND","Dto class %s not found.");
define("MSG_ERROR_DTO_NOT_MAPPED","Given data are not mapped in database!");
define("MSG_ERROR_DTO_PROPERTY_NOT_FOUND","Property %s of class %s not found.");
define("MSG_ERROR_EXECUTE_STATEMENT","Failed to execute statement!");
define("MSG_ERROR_FAILED_TO_CHANGE_USER_PASSWORD","Failed to change user password!");
define("MSG_ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE","Failed to update user password file!");
define("MSG_ERROR_FILE_NOT_FOUND","File not found!");
define("MSG_ERROR_INCOHERENT_FONCTION","Incoherent Function"); 
define("MSG_ERROR_INVALID_ALARM_NAME","Failed to retrieve alarm, invalid file name: ");
define("MSG_ERROR_INVALID_CONFIG","Incorrect media parameters.");
define("MSG_ERROR_INVALID_LICENSE","Invalid license!");
define("MSG_ERROR_INVALID_FILE","Invalid file!");
define("MSG_ERROR_INVALID_HOST_NAME","Invalid host name: must not be empty and must have less than 28 characters!");
define("MSG_ERROR_INVALID_IPV4","Invalid Ipv4 address!");
define("MSG_ERROR_INVALID_IPV4GATEWAY","Invalid Ipv4 gateway address!");
define("MSG_ERROR_INVALID_IPV4SUBNET","Invalid Ipv4 subnet mask address!");
define("MSG_ERROR_INVALID_IPV6","Invalid Ipv6 address!");
define("MSG_ERROR_INVALID_IPV6GATEWAY","Invalid Ipv6 gateway address!");
define("MSG_ERROR_INVALID_LINK_ID","Invalid link identifier!");
define("MSG_ERROR_INVALID_LINK_NAME","Invalid link name: must not be empty and must have less than 80 characters!");
define("MSG_ERROR_INVALID_MODEM_TYPE","Invalid modem type!");
define("MSG_ERROR_INVALID_MODULE_SELECTED","Invalid module identifier selected.");
define("MSG_ERROR_INVALID_OPERATION_STATUS","Unexpected operation result!");
define("MSG_ERROR_INVALID_PORT_OUT","Invalid port out!");
define("MSG_ERROR_INVALID_PORT","Invalid port!");
define("MSG_ERROR_INVALID_TEST_THRESHOLD_PARAMETERS","Invalid threshold parameters!");
define("MSG_ERROR_INVALID_USER_NEW_CREDENTIALS","Invalid new credentials for user!");
define("MSG_ERROR_IO_EXCEPTION","Input/output error!");
define("MSG_ERROR_LAST_MARKER_BADLY_SET","Last marker badly positionned!");
define("MSG_ERROR_LINK_ALREADY_EXIST","A link already exists (or it is being removed)!");
define("MSG_ERROR_LINK_HARDWARE_CONFIG","Link cannot be added because the configuration of the OTDR module or the switch is invalid!");
define("MSG_ERROR_LINK_NO_MODULE","No OTDR module setup!");
define("MSG_ERROR_LINK_NOT_FOUND","Link unknown!");
define("MSG_ERROR_LINK_UNKNOWN","Link Unknown!"); 
define("MSG_ERROR_MEASURE_BAD_TIME","Measure couldn't be started because duration is invalid!");
define("MSG_ERROR_MEASURE_BAD_TIMESLOT","Measure couldn't be started because we are in the inactive period (timeslot)");
define("MSG_ERROR_MEASURE_FAILED","Failed to start the measurement");
define("MSG_ERROR_MEASURE_NOT_PROGRAMMED","Measurement couldn't be started");
define("MSG_ERROR_MEDIA","Failure: ");
define("MSG_ERROR_MISSING_TEST_THRESHOLD_PARAMETERS","Test threshold parameters missing!");
define("MSG_ERROR_MISSING_OTDR_TRACE","OTDR trace not found!");
define("MSG_ERROR_MODEM_NOT_AVAILABLE","Modem not available!");
define("MSG_ERROR_MOD_MISSING","Module Missing!"); 
define("MSG_ERROR_NO_BACKUP_FOUND","Restore error, backup file wasn't found!");
define("MSG_ERROR_NO_LINE_STRING","No LineString found in kml file!");
define("MSG_ERROR_NO_LINE_STRING_COORDINATES","No coordinate found in kml file!");
define("MSG_ERROR_NO_PLACEMARK","No placemark of type PlaceMark found in kml file!");
define("MSG_ERROR_ONE_MEASURE_ON_DEMAND","Only one measurement can be started simultaneously!");
define("MSG_ERROR_ONE_TEST_ON_DEMAND","Only one test on demand can be started simultaneously!");
define("MSG_ERROR_ONLY_ONE_TEST_SETUP","Only one monitoring test can be setup simultaneously!");
define("MSG_ERROR_OPENING_DATABASE","Failed to open database!");
define("MSG_ERROR_OPENING_SOCKET","Failed to connect to OTU application!");
define("MSG_ERROR_OPENING_TRANSACTION","Save operations failed due to transaction opening failure!");
define("MSG_ERROR_OPERATION_ALLREADY_RUNNING","Failed, the operation is allready running!");
define("MSG_ERROR_OPTION_MODEM_NOT_SET","Modem option not set!");
define("MSG_ERROR_OTU_APPLICATION_NOT_AVAILABLE","OTU application not available!");
define("MSG_ERROR_OTU_APPLICATION_STARTING","OTU application is starting...");
define("MSG_ERROR_OTU_APPLICATION_REBOOTING","OTU application is rebooting...");
define("MSG_ERROR_OTU_APPLICATION_RESCUE","OTU is in RESCUE mode.");
define("MSG_ERROR_OTU_APPLICATION_UPGRADE","OTU application is upgraded...");
define("MSG_ERROR_OTU_AUTHENTIFICATION_FAILURE","Authentification failure on OTU parser!");
define("MSG_ERROR_PARAM_MISSING","Parameter Missing!"); 
define("MSG_ERROR_PORT_OTU","Error retrieving OTU application port!");
define("MSG_ERROR_READING_APC","Error reading shared memory");
define("MSG_ERROR_READING_SOCKET","Failed to communicate to OTU application!");
define("MSG_ERROR_REG_MEAS_FAILED","Measurement registration failed!"); 
define("MSG_ERROR_REF_FILE_PARMETER_ERROR","Reference file parameter error");
define("MSG_ERROR_REMOTE_HOST_ATTEMPT_TO_SEND_DATA","Remote host attempt to send data!");
define("MSG_ERROR_ROLLBACK_TRANSACTION","Cancelling save operations failed!");
define("MSG_ERROR_SAA_ALLREADY_RUNNING","Failed, the SmartAccessAnywhere setup is allready running!");
define("MSG_ERROR_SAA_CONNECTION_FAILED","Failed to open Smart Access Anywhere connection!");
define("MSG_ERROR_SNMP_INVALID_COMMUNITY","Invalid community!");
define("MSG_ERROR_SNMP_INVALID_HEARTBEAT_PERIOD","Invalid snmp heartbeat period");
define("MSG_ERROR_SNMP_INVALID_PORT","Invalid port");
define("MSG_ERROR_SNMP_INVALID_SERVER_NAME","Invalid manager name or address");
define("MSG_ERROR_SNMP_INVALID_TEST_MESSAGE","Invalid trap message.");
define("MSG_ERROR_START_EMAIL_TEST","Failure to send Email: ");
define("MSG_ERROR_START_SMS_TEST","Failure to send SMS: ");
define("MSG_ERROR_START_MEASURE","Failure to start measure! ");
define("MSG_ERROR_STOP_MEASURE","Failure to stop measure! ");
define("MSG_ERROR_SWITCH_BUFFER_ERROR","Wrong Switch Buffer!"); 
define("MSG_ERROR_SWITCH_BUFFER_SIZE","Wrong Switch Buffer Size!"); 
define("MSG_ERROR_SYSTEM_USER_PASSWORD_CANNOT_BE_CHANGED","System user password cannot be changed!");
define("MSG_ERROR_TABLE_NOT_FOUND","Database table not found!");
define("MSG_ERROR_TEST_ADD_ERROR","Test addition error!");    
define("MSG_ERROR_TEST_ADD_LOC","Problem with localisation in test!");
define("MSG_ERROR_TEST_ALLOCATE_MEMORY","Problem to allocate test memory!");
define("MSG_ERROR_TEST_ALREADY_EXIST","A test already exists on the link or it is being removed!");
define("MSG_ERROR_TEST_BAD_MARKER_BUFFER","Bad markers buffer for test!");
define("MSG_ERROR_TEST_BAD_TIMESLOT","Test couldn't be started because we are in the inactive period (timeslot)");
define("MSG_ERROR_TEST_FAILED","Failed to start the test on demand");
define("MSG_ERROR_TEST_FUNCT","Test function incoherent!");
define("MSG_ERROR_TEST_FUNCT_MISS","Test function missing!");
define("MSG_ERROR_TEST_MISS_LINK","Missing test link!");
define("MSG_ERROR_TEST_MISS_REF_TRACE","Missing test otdr reference trace!");
define("MSG_ERROR_TEST_NO_PARAM","Missing test parameters!");
define("MSG_ERROR_TEST_NOT_FOUND","Monitoring test not found!");
define("MSG_ERROR_TEST_NOT_PROGRAMMED","Test couldn't be executed!");
define("MSG_ERROR_TEST_OK","Test addition successful");
define("MSG_ERROR_TEST_REF_PARAM","Problem with otdr trace reference parameters in test!");
define("MSG_ERROR_TEST_SAVE_CONFIG","Problem to save test configuration!");
define("MSG_ERROR_TEST_SAVE_DESC","Problem to save test description!");
define("MSG_ERROR_TEST_SAVE_INFO","Problem to save test info!");
define("MSG_ERROR_TEST_SIZE_BUFFER_MARKER","Wrong size marker buffer for test!");
define("MSG_ERROR_TEST_TEST_RUNNING","Test running, impossible to modify test!");
define("MSG_ERROR_TEST_TOO_MUCH_LOC","Too much localizations traces!");
define("MSG_ERROR_TEST_TOO_MUCH_TESTS","Too much tests!");
define("MSG_ERROR_TEST_TYPE","Unknown test type!");
define("MSG_ERROR_TEST_UNDEFINED_TEST","Undefined test!");
define("MSG_ERROR_TEST_UNDEFINED","Undefined error with test!");
define("MSG_ERROR_TEST_UPDATE_FAILED","Test update failed!");
define("MSG_ERROR_TOO_MANY_LINE_STRING","Kml file must contain only one route with one LineString!");
define("MSG_ERROR_UNDEFINED","Undefined error"); 
define("MSG_ERROR_USER_PASSWORD_NOT_FOUND","User with the given password was not found!");
define("MSG_ERROR_WRITING_APC","Error writing in shared memory");
define("MSG_ERROR_WRITTING_SOCKET","Error writting on Otu parser socket!");
define("MSG_ERROR_WRONG_FONCTION","Wrong Module Function"); 
define("MSG_ERROR_WRONG_LASER","Wrong Laser"); 
define("MSG_ERROR_WRONG_PULSE","Wrong Pulse"); 
define("MSG_ERROR_WRONG_RANGE","Wrong Range!"); 
define("MSG_ERROR_WRONG_RES","Wrong Resolution"); 
define("MSG_FRENCH","Français");
define("MSG_INVALID_LOG_LEVEL_PARAMETER","Invalid log level parameter, should be: %s");
define("MSG_INVALID_VALUE_EXCEPTION","Invalid value for parameter: %s");
define("MSG_INVALID_STATUS","Invalid status for the operation!");
define("MSG_IO_EXCEPTION","Input/Output disk error!");
define("MSG_LANGUAGE","Language");
define("MSG_LINK","Link");
define("MSG_LOGIN","Login");
define("MSG_LOGIN_WINDOW_TITLE","Login");
define("MSG_MEAS_ADD_OK","Add measurement successfull"); 
define("MSG_MEASURE_AVAILABLE","Measure result available.");
define("MSG_MEASURE_INIT","Measurement init in progress...");
define("MSG_MEASURE_IN_PROGRESS","Measurement in progress...");
define("MSG_MEASURE_WAITING","Wait before measurement is starting...");
define("MSG_NO_JS","JavaScript required to launch the application. Please activate the JavaScript in your browser options.");
define("MSG_PORT","Port");
define("MSG_PARSER_COMMAND_FAILURE","Command execution failure!");
define("MSG_PARSER_COMMAND_TIMEOUT","Command execution failure: internal OTU connection failed!");
define("MSG_PASSWORD","Password");
// define("MSG_SEND_SMS_MESSAGE","Test SMS sent by OTU: %s");
// define("MSG_SEND_SNMP_MESSAGE","TEST sent from OTU: %s");
define("MSG_SPLASH_SCREEN_MESSAGE","Loading in progress...");
define("MSG_SOCKET_ERROR","Otu parser socket error!");
// define("MSG_TEST_EMAIL","Test sent from OTU: ");

//OTU resources
define("OTU_RES_NAME_BASE","OTU");   // Associes a la ressource UNIT
define("OTU_RES_NAME_EMAIL","Email");
define("OTU_RES_NAME_EXTERNAL_OTAU","External OTAU");
define("OTU_RES_NAME_INTERNAL_OTAU","Internal OTAU");
define("OTU_RES_NAME_MODEM","Modem");
define("OTU_RES_NAME_NETWORK","Network");   	   // Associes a la ressource COM
define("OTU_RES_NAME_NETWORK_MODEM","Network modem");
define("OTU_RES_NAME_OPTICAL_MODULE","Optical module");
define("OTU_RES_NAME_RELAY_CARD","relay card");
define("OTU_RES_NAME_SERVER","Server");
define("OTU_RES_NAME_SMS","SMS");
define("OTU_RES_NAME_UNKNOWN","Unknown");
define("OTU_RES_TIMESTAMP","Timestamp");
define("OTU_RES_SEVERITY","Severity");
define("OTU_RES_LINK","Link");
define("OTU_RES_DESCRIPTION","Description");


//OTU alarms
define("ACQUISITION_TIME","acquisition time");
define("ALARM_SWITCH","Switch internal error");
define("ALARM_MODULE","OTDR Module internal error");
define("AUTOTEST_TEST","Autotest error");
define("BACK_TO_NORMAL_STATE","Back to normal");
define("END_OF_SURVEY","End of survey");
define("HARD_DISK_FREE_SPACE","Not enough hard disk space");
define("HEART_BEAT_SENT_TO_ONMS","Heart beat sent to ONMS");
define("INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE","Incoherence with RAMAN acquisition mode");
define("INITIALISATION_FAILURE_DUE_TO_HARDWARE","Hardware problem");
define("INITIALISATION_FAILURE_DUE_TO_SOFTWARE","Software problem");
define("INJECTION_FAILURE","Injection failure");
define("INNER_APPLICATION_COMMUNICATION_PROBLEM","OTU inner application communication issue");
define("LINK_BREAK","Fiber break");
define("LINKS_BACK_TO_AVAILABLE","Links are back to available.");
define("LOCAL_MODE","Local mode");
define("MISSING_REFERENCE_FILE","Missing reference file");
define("MODULE_AUTOCONFIGURATION","OTDR Module autoconfiguration");
define("MODULE_TEMPERATURE","Module temperature");
define("MONITORING_CYCLE","Monitoring cycle");
define("MONITORING_TEST_DRIFT","Monitoring test drift");
define("NO_PROBLEM_DETECTED","No problem detected");
define("NON_REFLECTIVE_FAILURE","Non reflective event");
define("OTDR_TRACE_STORAGE","OTDR trace storage problem");
define("OTU_ALARM","Alarm %s");
define("OTU_ALARM_CONFIRMEE","Alarm confirmed");
define("OTU_ALARM_GENERIC_MESSAGE","Generic message"); 
define("OTU_ALARM_NON_CONFIRMEE","Alarm not confirmed"); 
define("OTU_ALARM_OVERFLOW","Alarm overflow");
define("OTU_ALARM_REBUID_CLEAR","Alarm cleared after rebuild"); 
define("OTU_ALARM_HDD_FAILED","HDD Failed");
define("OTU_ALARM_HDD_FAILED_USE_BACKUP","HDD Failed, use backup");
define("OTU_ALARM_SEQ_STOPPED","Sequencer stopped");
define("OTU_ALARM_CRITICAL","Critical");
define("OTU_ALARM_INDETERMINATE","Indeterminate");
define("OTU_ALARM_MAJOR","Major");
define("OTU_ALARM_MINOR","Minor");
define("OTU_ALARM_WARNING","Warning");
define("OTU_SYST_ALARM_POWER_FAILURE","Power failure");
define("PEAK","Peak");
define("PERSISTENT_FAILURE","Persistent failure");
define("PON_FAILURE","Pon test failure");
define("OTU_SYST_REFERENCE_DRIFT_FAILURE","Reference trace drift");
define("RAMAN_POWER_DETECTION","RAMAN power detection");
define("RAMAN_POWER_DECREASE","RAMAN power decreased");
define("REBOOT","Reboot");
define("REFLECTIVE_FAILURE","Reflective failure");
define("SIGNAL_DETECTED_ON_FIBER","Signal detected on fiber");
define("SPLICE_FAILURE","Splice detection failure");
define("SWITCH_AUTOCONFIGURATION","Switch autoconfiguration");
define("SYSTEM_FILE","System file");
define("TEMPORARY_PROBLEM","Temporary problem");
define("TEST_MEDIA","Media test");
define("TIMEOUT_ON_MONITORING_TEST_CYCLE","Timeout on monitoring cycle");
define("THRESHOLD_LEVEL_EXCEEDED","Threshold crossed");
define("CONNECTOR_FAILURE","Connector");
define("CONNECTOR_FIBER_CUT_FAILURE","Fiber Cut (Connector)");
define("CONNECTOR_ATTENUATION_FAILURE","Attenuation (Connector)");
define("SPLICE_BREAK","Splice broken or APC patchcord disconnected");
define("CONNECTOR_BREAK","Patchcord disconnected or excessive bending");
define("FIBER_BREAK","Fiber Break");
define("SPLICE_ATTENUATION","Fiber bending on splice or on APC patchcord");
define("CONNECTOR_ATTENUATION","Patchcord bending, dirty, loose");
define("FIBER_ATTENUATION","Fiber bending");
define("NEW_REFERENCE_REQUIRED","Fiber change: New reference required");
define("UNKNOW_ALARM","Unknown alarm");
define("UNKNOWN_CAUSE","Unknown cause");
?>
